USE MASTER;
GO

-- Compare columns of dm_exec_requests, dm_exec_sessions, dm_exec_connections, sysprocesses
SELECT Name, SUM([dm_exec_requests]) AS [dm_exec_requests], SUM([dm_exec_sessions]) AS [dm_exec_sessions], SUM([dm_exec_connections]) AS [dm_exec_connections], SUM([sysprocesses]) AS [sysprocesses]
FROM (
	SELECT C.NAME, 
	CASE WHEN o.NAME = 'dm_exec_requests' THEN 1 ELSE 0 END AS  [dm_exec_requests],
	CASE WHEN o.NAME = 'dm_exec_sessions' THEN 1 ELSE 0 END AS  [dm_exec_sessions],
	CASE WHEN o.NAME = 'dm_exec_connections' THEN 1 ELSE 0 END AS  [dm_exec_connections],
	CASE WHEN o.NAME = 'sysprocesses' THEN 1 ELSE 0 END AS  [sysprocesses]
	FROM syscolumns c
	JOIN sysobjects o on o.id = c.id
	WHERE o.name IN (	'dm_exec_requests',
						'dm_exec_sessions',
						'dm_exec_connections',
						'sysprocesses' )
	) A
GROUP BY Name
ORDER BY NAME, [sysprocesses] DESC, [dm_exec_requests] DESC
GO

SELECT *
FROM sys.dm_exec_requests;
GO

SELECT	session_id,
	status,
	blocking_session_id,
	wait_type,
	wait_time,
	wait_resource,
	transaction_id 
FROM sys.dm_exec_requests 
WHERE status = N'suspended';
GO

-- Batch to run on other connections
BEGIN TRANSACTION
SELECT @@SPID
SELECT * FROM PUBS..authors (UPDLOCK)
WAITFOR DELAY '00:00:05'
COMMIT TRANSACTION

-- Connections
SELECT *
FROM sys.dm_exec_connections;
GO

-- Sessions (may return more than dm_exec_requests if the session is not running a command)
SELECT *
FROM sys.dm_exec_sessions;
GO